[pypy-commit] pypy default: Spelling and grammatical errors spotted by lintian

stefanor noreply at buildbot.pypy.org
Wed Oct 10 11:30:05 CEST 2012


Author: Stefano Rivera <stefano at rivera.za.net>
Branch: 
Changeset: r57966:188d16ca09be
Date: 2012-10-10 11:28 +0200
http://bitbucket.org/pypy/pypy/changeset/188d16ca09be/

Log:	Spelling and grammatical errors spotted by lintian

diff --git a/py/_io/capture.py b/py/_io/capture.py
--- a/py/_io/capture.py
+++ b/py/_io/capture.py
@@ -176,7 +176,7 @@
 
 
 class StdCaptureFD(Capture):
-    """ This class allows to capture writes to FD1 and FD2
+    """ This class allows capturing writes to FD1 and FD2
         and may connect a NULL file to FD0 (and prevent
         reads from sys.stdin).  If any of the 0,1,2 file descriptors
         is invalid it will not be captured.
@@ -267,8 +267,8 @@
         return l
 
 class StdCapture(Capture):
-    """ This class allows to capture writes to sys.stdout|stderr "in-memory"
-        and will raise errors on tries to read from sys.stdin. It only
+    """ This class allows capturing writes to sys.stdout|stderr "in-memory"
+        and will raise errors on read attempts from sys.stdin. It only
         modifies sys.stdout|stderr|stdin attributes and does not
         touch underlying File Descriptors (use StdCaptureFD for that).
     """
diff --git a/pypy/bin/reportstaticdata.py b/pypy/bin/reportstaticdata.py
--- a/pypy/bin/reportstaticdata.py
+++ b/pypy/bin/reportstaticdata.py
@@ -2,9 +2,9 @@
 
 """
 Usage: reportstaticdata.py [-m1|-m2|-t] [OPTION]... FILENAME
-Print a report for the static data informations contained in FILENAME
+Print a report for the static data information contained in FILENAME
 
-The static data informations are saved in the file staticdata.info when
+The static data information is saved in the file staticdata.info when
 passing --dump_static_data_info to translate.py.
 
 Options:
diff --git a/pypy/jit/backend/cli/methodfactory.py b/pypy/jit/backend/cli/methodfactory.py
--- a/pypy/jit/backend/cli/methodfactory.py
+++ b/pypy/jit/backend/cli/methodfactory.py
@@ -27,7 +27,7 @@
         return self.dynmeth.CreateDelegate(delegatetype, consts)
 
 
-# the assemblyData singleton contains the informations about the
+# the assemblyData singleton contains the information about the
 # assembly we are currently writing to
 class AssemblyData:
     assembly = None
diff --git a/pypy/jit/backend/model.py b/pypy/jit/backend/model.py
--- a/pypy/jit/backend/model.py
+++ b/pypy/jit/backend/model.py
@@ -97,7 +97,7 @@
         The FailDescr is the descr of the original guard that failed.
 
         Optionally, return a ``ops_offset`` dictionary.  See the docstring of
-        ``compiled_loop`` for more informations about it.
+        ``compiled_loop`` for more information about it.
         """
         raise NotImplementedError
 
diff --git a/pypy/jit/metainterp/optimizeopt/unroll.py b/pypy/jit/metainterp/optimizeopt/unroll.py
--- a/pypy/jit/metainterp/optimizeopt/unroll.py
+++ b/pypy/jit/metainterp/optimizeopt/unroll.py
@@ -317,7 +317,7 @@
         except BadVirtualState:
             raise InvalidLoop('The state of the optimizer at the end of ' +
                               'peeled loop is inconsistent with the ' +
-                              'VirtualState at the begining of the peeled ' +
+                              'VirtualState at the beginning of the peeled ' +
                               'loop')
         jumpop.initarglist(jumpargs)
 
diff --git a/pypy/module/pypyjit/interp_resop.py b/pypy/module/pypyjit/interp_resop.py
--- a/pypy/module/pypyjit/interp_resop.py
+++ b/pypy/module/pypyjit/interp_resop.py
@@ -63,7 +63,7 @@
     """ set_optimize_hook(hook)
 
     Set a compiling hook that will be called each time a loop is optimized,
-    but before assembler compilation. This allows to add additional
+    but before assembler compilation. This allows adding additional
     optimizations on Python level.
 
     The hook will be called with the pypyjit.JitLoopInfo object. Refer to it's
diff --git a/pypy/tool/bench/htmlreport.py b/pypy/tool/bench/htmlreport.py
--- a/pypy/tool/bench/htmlreport.py
+++ b/pypy/tool/bench/htmlreport.py
@@ -226,7 +226,7 @@
         )
 
     def render_revision_header(self, sample):
-        """return a header for a report with informations about
+        """return a header for a report with information about
         committer, messages, revision date.
         """
         revision_id = pyhtml.li('Revision ID: %s' % (sample.revision_id,))
diff --git a/pypy/tool/bench/result.py b/pypy/tool/bench/result.py
--- a/pypy/tool/bench/result.py
+++ b/pypy/tool/bench/result.py
@@ -13,7 +13,7 @@
 
         
 class PerfResultCollection(object):
-    """Holds informations about several PerfResult objects. The
+    """Holds information about several PerfResult objects. The
     objects should have the same test_id and revision_id"""
     
     def __init__(self, results=None):
@@ -166,7 +166,7 @@
     count = py.std.itertools.count() 
     def annotate(self, result):
         """Try to put extra information for each revision on the
-        PerfResult objects. These informations are retrieved from a
+        PerfResult objects. These information are retrieved from a
         branch object.
         """
         #if self.branch is None:
diff --git a/pypy/tool/memusage/log2gnumeric.py b/pypy/tool/memusage/log2gnumeric.py
--- a/pypy/tool/memusage/log2gnumeric.py
+++ b/pypy/tool/memusage/log2gnumeric.py
@@ -7,7 +7,7 @@
 
     $ PYPYLOG=gc-collect,jit-mem:logfile pypy your-program.py
 
-This will produce "logfile", containing informations about the memory used by
+This will produce "logfile", containing information about the memory used by
 the GC and the number of loops created/freed by the JIT.
 
 If you want, you can also measure the amout of used memory as seen by the OS
diff --git a/pypy/tool/sourcetools.py b/pypy/tool/sourcetools.py
--- a/pypy/tool/sourcetools.py
+++ b/pypy/tool/sourcetools.py
@@ -120,7 +120,7 @@
 # various helper functions
 #
 class MyStr(str):
-    """ custom string which allows to add attributes. """
+    """ custom string which allows adding attributes. """
 
 def newcode(fromcode, **kwargs):
     names = [x for x in dir(fromcode) if x[:3] == 'co_']
diff --git a/pypy/translator/goal/timing.py b/pypy/translator/goal/timing.py
--- a/pypy/translator/goal/timing.py
+++ b/pypy/translator/goal/timing.py
@@ -1,5 +1,5 @@
 
-""" Module for keeping detailed informations about
+""" Module for keeping detailed information about
 times of certain driver parts
 """
 
diff --git a/pypy/translator/microbench/pybench/platform.py b/pypy/translator/microbench/pybench/platform.py
--- a/pypy/translator/microbench/pybench/platform.py
+++ b/pypy/translator/microbench/pybench/platform.py
@@ -811,7 +811,7 @@
                  split=re.compile('[\s,]').split):
 
     """ Queries the given executable (defaults to the Python interpreter
-        binary) for various architecture informations.
+        binary) for various architecture information.
 
         Returns a tuple (bits,linkage) which contain information about
         the bit architecture and the linkage format used for the
diff --git a/pypy/translator/platform/__init__.py b/pypy/translator/platform/__init__.py
--- a/pypy/translator/platform/__init__.py
+++ b/pypy/translator/platform/__init__.py
@@ -215,7 +215,7 @@
         largs = self._link_args_from_eci(eci, standalone)
         return self._link(cc_link, ofiles, largs, standalone, exe_name)
 
-    # below are some detailed informations for platforms
+    # below are some detailed information for platforms
 
     def include_dirs_for_libffi(self):
         dirs = self._include_dirs_for_libffi()
diff --git a/pypy/translator/tool/staticsizereport.py b/pypy/translator/tool/staticsizereport.py
--- a/pypy/translator/tool/staticsizereport.py
+++ b/pypy/translator/tool/staticsizereport.py
@@ -201,7 +201,7 @@
     f = infofile.open('w')
     pickle.dump(info, f)
     f.close()
-    log.info('static data informations dumped to %s' % infofile)
+    log.info('static data information dumped to %s' % infofile)
     return infofile
 
 


More information about the pypy-commit mailing list
diff --git a/pypy/module/posix/app_posix.py b/pypy/module/posix/app_posix.py
--- a/pypy/module/posix/app_posix.py
+++ b/pypy/module/posix/app_posix.py
@@ -198,7 +198,7 @@
     def wait3(options):
         """ wait3(options) -> (pid, status, rusage)
 
         Wait for completion of a child process and provides resource usage informations
         """
         from _pypy_wait import wait3
         return wait3(options)
@@ -206,7 +206,7 @@
     def wait4(pid, options):
         """ wait4(pid, options) -> (pid, status, rusage)
 
-        Wait for completion of the child process "pid" and provides resource usage informations
+        Wait for completion of the child process "pid" and provides resource usage information
         """
         from _pypy_wait import wait4
         return wait4(pid, options)
@@ -198,7 +198,7 @@
         """ wait3(options) -> (pid, status, rusage)
 
-        Wait for completion of a child process and provides resource usage informations
+        Wait for completion of a child process and provides resource usage information
         """
         from _pypy_wait import wait3